---
title: <span class="badge builder"></span> PrometheusDataqueryScope
---
# <span class="badge builder"></span> PrometheusDataqueryScope

## Constructor

```python
PrometheusDataqueryScope()
```
## Methods

### <span class="badge object-method"></span> build

Builds the object.

```python
def build() -> prometheus.PrometheusDataqueryScope
```

### <span class="badge object-method"></span> matchers

```python
def matchers(matchers: str) -> typing.Self
```

## See also

 * <span class="badge object-type-class"></span> [PrometheusDataqueryScope](./object-PrometheusDataqueryScope.md)
